@@ -18,8 +18,6 @@ def examples_client(request):
         app = module.create_app(conf="test")
 
     with app.app_context():
-        if "sqlalchemy" in app.extensions:
-            app.extensions["sqlalchemy"].db.create_all()
         with app.test_client() as client:
             yield client
 
